@@ -1,9 +1,9 @@
 from django.contrib import admin
-from image_cropping.admin import ImageCroppingAdmin
+from image_cropping.admin import ImageCroppingMixin
 from models import Image, ImageFK
 
 
-class ImageFKAdmin(ImageCroppingAdmin, admin.ModelAdmin):
+class ImageFKAdmin(ImageCroppingMixin, admin.ModelAdmin):
     pass
 
 
