@@ -3,6 +3,7 @@ import inspect
 import warnings
 
 from django.db.models import get_model, ObjectDoesNotExist
+from django import forms
 from django.contrib.admin.widgets import AdminFileWidget, ForeignKeyRawIdWidget
 from django.conf import settings
 
@@ -10,14 +11,12 @@ from easy_thumbnails.files import get_thumbnailer
 
 logger = logging.getLogger(__name__)
 
-ADMIN_THUMBNAIL_SIZE = getattr(settings, 'IMAGE_CROPPING_THUMB_SIZE', (300, 300))
-
 
 def thumbnail(image_path):
     thumbnailer = get_thumbnailer(image_path)
     thumbnail_options = {
         'detail': True,
-        'size': ADMIN_THUMBNAIL_SIZE,
+        'size': getattr(settings, 'IMAGE_CROPPING_THUMB_SIZE', (300, 300)),
     }
     thumb = thumbnailer.get_thumbnail(thumbnail_options)
     return thumb.url
@@ -57,6 +56,19 @@ class ImageCropWidget(AdminFileWidget, CropWidget):
         return super(AdminFileWidget, self).render(name, value, attrs)
 
 
+class HiddenImageCropWidget(forms.HiddenInput, CropWidget):
+    def render(self, name, value, attrs=None):
+        if not attrs:
+            attrs = {}
+        # we need to hide it the whole field by JS because the admin
+        # doesn't yet support hidden fields:
+        # https://code.djangoproject.com/ticket/11277
+        attrs['data-hide-field'] = True
+        if value:
+            attrs.update(get_attrs(value, name))
+        return super(HiddenImageCropWidget, self).render(name, value, attrs)
+
+
 class CropForeignKeyWidget(ForeignKeyRawIdWidget, CropWidget):
     def __init__(self, *args, **kwargs):
         self.field_name = kwargs.pop('field_name')
